/*
**  CWContainer.h
**
**  Copyright (c) 2002-2004
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**  
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**  Lesser General Public License for more details.
**  
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

#ifndef _Pantomime_H_CWContainer
#define _Pantomime_H_CWContainer

#import <Foundation/NSEnumerator.h>
#import <Foundation/NSObject.h>

@class CWMessage;

/*!
  @class CWContainer
  @discussion This class is a simple placeholder used when doing message threading.
              A container is composed of a CWMessage instance which might be nil, a parent,
	      child and next CWContainer instances. For a full description of the implemented
	      algorithm, see <a href="http://www.jwz.org/doc/threading.html">message threading</a>.
*/
@interface CWContainer : NSObject
{
  @public
    CWContainer *parent; // do not retain
    CWContainer *child, *next;
    CWMessage *message; // Not retained!
}

+ (CWContainer *)newContainer;

- (void) setParent: (CWContainer *) theParent;
- (CWContainer *)parent;

- (void) setChild: (CWContainer *) theChild;
- (CWContainer *)child;

- (void) setNext: (CWContainer *) theNext;
- (CWContainer *)next;

- (void)setMessage:(CWMessage *)aMsg;
- (CWMessage *)message;

- (BOOL)findChild:(CWContainer *)aChild;

- (void)reverseChildren;

- (unsigned)siblingCount;

- (unsigned)childrenCount;

@end

#endif // _Pantomime_H_CWContainer
